@@ -33,6 +33,12 @@
 #'
 #' @export
 f7Badge <- function(..., color = NULL) {
+  if (!is.null(color)) {
+    if (!(color %in% getF7Colors())) {
+      stop("Color must be one of: ", paste(getF7Colors(), collapse = ", "))
+    }
+  }
+
   badgeCl <- "badge"
   if (!is.null(color)) badgeCl <- paste0(badgeCl, " color-", color)
   shiny::tags$span(class = badgeCl, ...)
