@@ -44,4 +44,4 @@ $.extend(f7DateBinding, {
   }
 });
 
-Shiny.inputBindings.register(f7DateBinding);
+Shiny.inputBindings.register(f7DateBinding, 'f7.date');
