@@ -47,4 +47,4 @@ $.extend(f7ToggleBinding, {
   }
 });
 
-Shiny.inputBindings.register(f7ToggleBinding);
+Shiny.inputBindings.register(f7ToggleBinding, 'f7.toggle');
